# How to Report an Issue

If you would like to report a problem you find when using `you-get`, please open a [Pull Request](https://github.com/soimort/you-get/pulls), which should include:

1. A detailed description of the encountered problem;
2. At least one commit, addressing the problem through some unit test(s).
   * Examples of good commits: [#2675](https://github.com/soimort/you-get/pull/2675/files), [#2680](https://github.com/soimort/you-get/pull/2680/files), [#2685](https://github.com/soimort/you-get/pull/2685/files)

PRs that fail to meet the above criteria may be closed summarily with no further action.

A valid PR will remain open until its addressed problem is fixed.



# 如何汇报问题

为了防止对 GitHub Issues 的滥用，本项目不接受一般的 Issue。

如您在使用 `you-get` 的过程中发现任何问题，请开启一个 [Pull Request](https://github.com/soimort/you-get/pulls)。该 PR 应当包含：

1. 详细的问题描述；
2. 至少一个 commit，其内容是**与问题相关的**单元测试。**不要通过随意修改无关文件的方式来提交 PR！**
   * 有效的 commit 示例：[#2675](https://github.com/soimort/you-get/pull/2675/files), [#2680](https://github.com/soimort/you-get/pull/2680/files), [#2685](https://github.com/soimort/you-get/pull/2685/files)

不符合以上条件的 PR 可能被直接关闭。

有效的 PR 将会被一直保留，直至相应的问题得以修复。
